# Generated by Django 2.1.2 on 2018-10-23 10:55

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='About',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=255)),
                ('description', models.TextField()),
                ('image', models.ImageField(upload_to='about/')),
            ],
            options={
                'abstract': False,
            },
        ),
    ]



from django.test import TestCase
from djtools.about.services import get_about
from djtools.about.models import About


class ServicesTestCase(TestCase):
    def test_get_about(self):
        about = get_about()
        assert about is None

        first_about = About.objects.create(title="first")
        about = get_about()
        assert about == first_about

        About.objects.create(title="second")
        about = get_about()
        assert about == first_about
